@@ -5,18 +5,17 @@ import warnings
 import numpy as np
 import pandas as pd
 import pandas.compat as compat
-from pandas.util.decorators import Appender, cache_readonly
 
-from pandas_ml.compat import is_list_like
-from pandas_ml.core.generic import ModelPredictor, _shared_docs
-from pandas_ml.core.series import ModelSeries
-from pandas_ml.core.accessor import _AccessorMethods
 import pandas_ml.imbaccessors as imbaccessors
 import pandas_ml.skaccessors as skaccessors
 import pandas_ml.smaccessors as smaccessors
 import pandas_ml.snsaccessors as snsaccessors
-import pandas_ml.xgboost as xgboost
 import pandas_ml.util as util
+import pandas_ml.xgboost as xgboost
+from pandas_ml.compat import is_list_like, Appender, cache_readonly
+from pandas_ml.core.accessor import _AccessorMethods
+from pandas_ml.core.generic import ModelPredictor, _shared_docs
+from pandas_ml.core.series import ModelSeries
 
 
 class ModelFrame(ModelPredictor, pd.DataFrame):
@@ -413,15 +412,24 @@ class ModelFrame(ModelPredictor, pd.DataFrame):
               dict(funcname='fit_sample', returned='returned : sampling result'))
     def fit_sample(self, estimator, *args, **kwargs):
         # for imblearn
-        sampled_X, sampled_y = self._call(estimator, 'fit_sample', *args, **kwargs)
+        msg = ".fit_sample is deprecated. Use .fit_resample instead"
+        warnings.warn(msg, DeprecationWarning)
+        return self.fit_resample(estimator, *args, **kwargs)
+
+    @Appender(_shared_docs['estimator_methods'] %
+              dict(funcname='fit_resample', returned='returned : resampling result'))
+    def fit_resample(self, estimator, *args, **kwargs):
+        # for imblearn
+        sampled_X, sampled_y = self._call(estimator, 'fit_resample', *args, **kwargs)
         return self._wrap_sampled(sampled_X, sampled_y)
 
     @Appender(_shared_docs['estimator_methods'] %
               dict(funcname='sample', returned='returned : sampling result'))
     def sample(self, estimator, *args, **kwargs):
         # for imblearn
-        sampled_X, sampled_y = self._call(estimator, 'sample', *args, **kwargs)
-        return self._wrap_sampled(sampled_X, sampled_y)
+        msg = ".sample is deprecated. Use .fit_resample instead"
+        warnings.warn(msg, DeprecationWarning)
+        return self.fit_resample(estimator, *args, **kwargs)
 
     def _wrap_sampled(self, sampled_X, sampled_y):
         # revert sampled results to ModelFrame, index is being reset
@@ -454,7 +462,10 @@ class ModelFrame(ModelPredictor, pd.DataFrame):
                 # set inverse columns
                 estimator._pdml_original_columns = self.data.columns
             return transformed
-        except:     # noqa
+        except ImportError:
+            # raise patsy error
+            raise
+        except Exception as e:     # noqa
             return pd.DataFrame.transform(self, estimator, *args, **kwargs)
 
     @Appender(_shared_docs['estimator_methods'] %
@@ -575,24 +586,6 @@ class ModelFrame(ModelPredictor, pd.DataFrame):
         return _AccessorMethods(self, module_name='sklearn.cross_decomposition',
                                 attrs=attrs)
 
-    @property
-    @Appender(_shared_docs['skaccessor'] % dict(module='cross_validation'))
-    def cross_validation(self):
-        msg = '.cross_validation is deprecated. Use .ms or .model_selection'
-        warnings.warn(msg, FutureWarning, stacklevel=2)
-        return self._cross_validation
-
-    @property
-    @Appender(_shared_docs['skaccessor'] % dict(module='cross_validation'))
-    def crv(self):
-        msg = '.crv is deprecated. Use .ms or .model_selection'
-        warnings.warn(msg, FutureWarning, stacklevel=2)
-        return self._cross_validation
-
-    @cache_readonly
-    def _cross_validation(self):
-        return skaccessors.CrossValidationMethods(self)
-
     @property
     @Appender(_shared_docs['skaccessor_nolink'] % dict(module='decomposition'))
     def decomposition(self):
@@ -670,17 +663,6 @@ class ModelFrame(ModelPredictor, pd.DataFrame):
     def _gaussian_process(self):
         return skaccessors.GaussianProcessMethods(self)
 
-    @property
-    @Appender(_shared_docs['skaccessor'] % dict(module='grid_search'))
-    def grid_search(self):
-        msg = '.grid_search is deprecated. Use .ms or .model_selection'
-        warnings.warn(msg, FutureWarning, stacklevel=2)
-        return self._grid_search
-
-    @cache_readonly
-    def _grid_search(self):
-        return skaccessors.GridSearchMethods(self)
-
     @property
     def imbalance(self):
         """ Property to access ``imblearn``"""
@@ -728,17 +710,6 @@ class ModelFrame(ModelPredictor, pd.DataFrame):
         warnings.warn(msg, FutureWarning, stacklevel=2)
         return self._da
 
-    @property
-    @Appender(_shared_docs['skaccessor'] % dict(module='learning_curve'))
-    def learning_curve(self):
-        msg = '.learning_curve is deprecated. Use .ms or .model_selection'
-        warnings.warn(msg, FutureWarning, stacklevel=2)
-        return self._learning_curve
-
-    @cache_readonly
-    def _learning_curve(self):
-        return skaccessors.LearningCurveMethods(self)
-
     @property
     @Appender(_shared_docs['skaccessor'] % dict(module='linear_model'))
     def linear_model(self):
